using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;

namespace WindowsApplication5
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraGrid1.CreationFilter = new CheckBoxTextCreationFilter();
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[0].Columns["CheckBox"].EditorControl = this.ultraCheckEditor1;
        }        
    }

    public class CheckBoxTextCreationFilter : IUIElementCreationFilter
    {
        #region IUIElementCreationFilter Members

        void IUIElementCreationFilter.AfterCreateChildElements(UIElement parent)
        {
            // See if the elements is a CheckEditorCheckBoxUIElement
           if (parent is CheckEditorCheckBoxUIElement == false)            
                return;

            // Get the cell containing the element
            UltraGridCell cell = parent.GetContext(typeof(UltraGridCell)) as UltraGridCell;
            if (cell == null ||
                cell.Column.Key != "CheckBox")
            {
                return;
            }

            // Get the Text element inside the cell. 
            TextUIElement textUIElement = parent.GetDescendant(typeof(TextUIElement)) as TextUIElement;
            if (textUIElement == null)
                return;

            // Use the Text property of the cell to determine if it is checked or unchecked.
            // We cannot use Value here, because it doesn't get updated until the focus leaves the cell. 
            bool cellChecked = bool.Parse(cell.Text);

            // Set the text of the element based on the checked state. 
            if (cellChecked)
                // If the cell is checked. use the text from Column 1. 
                textUIElement.Text = cell.Row.Cells["Column 1"].Text;
            else
                // If it's not checked, use an empty string. 
                textUIElement.Text = string.Empty;
        }

        bool IUIElementCreationFilter.BeforeCreateChildElements(UIElement parent)
        {
            // do nothing
            return false;
        }

        #endregion
    }
}